==> haskell-unliftio-core-0.2.0.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unliftio-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unliftio-core
version:              0.2.0.1
visibility:           public
id:                   unliftio-core-0.2.0.1-DFzZctvkeWF1j2hnkeOBtq
key:                  unliftio-core-0.2.0.1-DFzZctvkeWF1j2hnkeOBtq
license:              MIT
copyright:            2017-2020 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Francesco Mazzoli
homepage:
    https://github.com/fpco/unliftio/tree/master/unliftio-core#readme

synopsis:             The MonadUnliftIO typeclass for unlifting monads to IO
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio-core>

category:             Control
abi:                  88e76e1a7df735dd22dfafda4661c96b
exposed:              True
exposed-modules:      Control.Monad.IO.Unlift
hidden-modules:       Paths_unliftio_core
import-dirs:          /usr/lib/ghc-8.10.1/site-local/unliftio-core-0.2.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/unliftio-core-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/unliftio-core-0.2.0.1
hs-libraries:         HSunliftio-core-0.2.0.1-DFzZctvkeWF1j2hnkeOBtq
depends:              base-4.14.0.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-unliftio-core/html/unliftio-core.haddock

haddock-html:         /usr/share/doc/haskell-unliftio-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unliftio-core-0.2.0.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unliftio-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unliftio-core
version:              0.2.0.1
visibility:           public
id:                   unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV
key:                  unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV
license:              MIT
copyright:            2017-2020 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Francesco Mazzoli
homepage:
    https://github.com/fpco/unliftio/tree/master/unliftio-core#readme

synopsis:             The MonadUnliftIO typeclass for unlifting monads to IO
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio-core>

category:             Control
abi:                  21cc92bb0b21da57ab8305e3de1dae51
exposed:              True
exposed-modules:      Control.Monad.IO.Unlift
hidden-modules:       Paths_unliftio_core
import-dirs:          /usr/lib/ghc-8.10.2/site-local/unliftio-core-0.2.0.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/unliftio-core-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/unliftio-core-0.2.0.1
hs-libraries:         HSunliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV
depends:              base-4.14.1.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-unliftio-core/html/unliftio-core.haddock

haddock-html:         /usr/share/doc/haskell-unliftio-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
